@@ -1011,6 +1011,7 @@ class LSsearch {
    **/
   public function __get($key) {
     $params = array (
+      'basedn',
       'sortBy',
       'sortDirection'
     );
@@ -1110,13 +1111,8 @@ class LSsearch {
     
     if ($va == $vb) return 0;
     
-    $val = array($va,$vb);
-    sort($val);
-    
-    if ($val[0]==$va)
-      return 1*$dir;
-      
-    return -1*$dir;
+    $val = strcoll(strtolower($va), strtolower($vb));
+    return $val*$dir;
   }
   
   /**
@@ -1319,5 +1315,6 @@ _("LSsearch : The function of the custum information %{name} is not callable.")
 LSerror :: defineError('LSsearch_15',
 _("LSsearch : Invalid predefinedFilter for LSobject type %{type} : %{label} (filter : %{filter}).")
 );
-
-?>
+LSerror :: defineError('LSsearch_16',
+_("LSsearch : Error during execution of the custom action %{customAction}.")
+);
